@@ -2,33 +2,38 @@ package deploy
 
 import (
 	"context"
+	"os"
+	"path/filepath"
+	"testing"
+
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/state"
-	"os"
-	"path/filepath"
-	"testing"
 )
 
 func TestMultipleDockerfile(t *testing.T) {
 	dir := t.TempDir()
 
-	f, err := os.Create(filepath.Join(dir, "Dockerfile"))
+	dockerfile, err := os.Create(filepath.Join(dir, "Dockerfile"))
 	require.NoError(t, err)
-	defer f.Close() // skipcq: GO-S2307
+	defer dockerfile.Close() // skipcq: GO-S2307
+
+	flyToml, err := os.Create(filepath.Join(dir, "fly.production.toml"))
+	require.NoError(t, err)
+	defer flyToml.Close() // skipcq: GO-S2307
+
+	cfg, err := appconfig.LoadConfig(flyToml.Name())
+	require.NoError(t, err)
+	cfg.Build = &appconfig.Build{
+		Dockerfile: "Dockerfile.from-fly-toml",
+	}
 
 	ctx := state.WithWorkingDirectory(context.Background(), dir)
 	err = multipleDockerfile(ctx, &appconfig.Config{})
+
 	assert.NoError(t, err)
 
-	err = multipleDockerfile(
-		ctx,
-		&appconfig.Config{
-			Build: &appconfig.Build{
-				Dockerfile: "Dockerfile.from-fly-toml",
-			},
-		},
-	)
-	assert.Error(t, err)
+	err = multipleDockerfile(ctx, cfg)
+	assert.ErrorContains(t, err, "fly.production.toml")
 }
